@@ -1,5 +1,7 @@
+import pytest
+
 import spectra
-import nose
+
 
 def test_polylinear():
     """
@@ -13,8 +15,9 @@ def test_polylinear():
     goal = ['#ffff00', '#ff8000', '#ff0000', '#800000', '#000000']
     assert(results == goal)
 
-@nose.tools.raises(ValueError)
+
 def test_polylinear_fail():
     colors = ['yellow', 'red', 'black']
     domain = [ 0, 50 ] # Domain has one too few items
-    spectra.scale(colors).domain(domain)
+    with pytest.raises(ValueError):
+        spectra.scale(colors).domain(domain)
